Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(227)

Unified Diff: content/browser/android/browser_jni_registrar.h

Issue 10697030: Register JNI for content_unittests. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Rebase Created 8 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « content/app/android/library_loader_hooks.cc ('k') | content/browser/android/browser_jni_registrar.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: content/browser/android/browser_jni_registrar.h
diff --git a/content/app/android/content_jni_registrar.h b/content/browser/android/browser_jni_registrar.h
similarity index 50%
copy from content/app/android/content_jni_registrar.h
copy to content/browser/android/browser_jni_registrar.h
index df83785016a3f64e6783594e1835fc390b50d77e..03505bb8f23c1207ecc13379837ac6519d8f6033 100644
--- a/content/app/android/content_jni_registrar.h
+++ b/content/browser/android/browser_jni_registrar.h
@@ -2,18 +2,18 @@
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
-#ifndef CONTENT_APP_ANDROID_CONTENT_JNI_REGISTRAR_H_
-#define CONTENT_APP_ANDROID_CONTENT_JNI_REGISTRAR_H_
+#ifndef CONTENT_BROWSER_ANDROID_BROWSER_JNI_REGISTRAR_H_
+#define CONTENT_BROWSER_ANDROID_BROWSER_JNI_REGISTRAR_H_
#include <jni.h>
namespace content {
namespace android {
-// Register all JNI bindings necessary for content.
-bool RegisterJni(JNIEnv* env);
+// Register all JNI bindings necessary for content browser.
+bool RegisterBrowserJni(JNIEnv* env);
} // namespace android
} // namespace content
-#endif // CONTENT_APP_ANDROID_CONTENT_JNI_REGISTRAR_H_
+#endif // CONTENT_BROWSER_ANDROID_BROWSER_JNI_REGISTRAR_H_
« no previous file with comments | « content/app/android/library_loader_hooks.cc ('k') | content/browser/android/browser_jni_registrar.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698